fluidRow(
  box(title = strong("Orthogonal Partial Least Squares Discriminant Analysis (OPLS-DA)"), solidHeader = T, status = "warning", width = 12,collapsible=T,
      p("OPLS-DA is introduced as an improvement of PLS-DA to discriminate two or more groups using multivariate data by 
        constructingregression models. Comparing to PLS-DA, OPLS-DA uses a single component as predictor for groups, and 
        the other components are orthogonal to the first one. OPLS-DA has been widely applied in metabolomics analysis to 
        identify metabolic biomarkers in amyotrophic lateral sclerosis (",
        span(a(em("Eur J Neurol.")," 2015. doi: 10.1111/ene.12851", style="color:blue", href = "http://onlinelibrary.wiley.com/doi/10.1111/ene.12851/full",target="_black")),
        "), and detect diagnostic markers of early-stage ovarian cancer (",
        span(a(em("Sci Rep.")," 2015. 5: 16351",style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/26573008", target="_black")), ").", 
       
        style = "color: black; font-size: 17px"
      )
  ),
  conditionalPanel("output.ShowUI",
        
#      box(title = strong("The Resulting Analysis Figures Generated by OPLS-DA"), solidHeader = T, status = "info", width = 12, collapsible=T,
##          (source("src/uicontrol/underConstruction.R",local=T)$value)
#           downloadButton('oplsda_plot_down', 'Download'), 
#           p(strong("Figure 1. Results for OPLS-DA"), style = "color:black; font-size:16px", align = "center"),
#           plotOutput("oplsda_graphplot")
#      )
 
####box(title=strong("The Resulting Figures Generated by OPLS-DA", style = "color:white"), 
####    solidHeader = T, status = "info", width = 12,collapsible=T,
####    (source("src/uicontrol/waitingPrompt.R",local=T)$value),
####
####    fluidRow(
####        column(width = 12, 
####               downloadButton('OPLS_plot_down', 'Download'),
####               plotOutput("OPLS_plot")
####               )
####    )
####    
####), 

box(title=strong("The Resulting Data Tables Generated by OPLS-DA", style = "color:white"), 
    solidHeader = T, status = "info", width = 12,collapsible=T,
    #(source("src/uicontrol/waitingPrompt.R", local=T)$value),
    conditionalPanel("!output.OPLS_table",
                     (source("src/uicontrol/waitingPrompt.R", local=T)$value)
    ),
    
    fluidRow(
        
        column(width=3, numericInput("cross_num", "Cross Number", value = 7, min = 2, max = 9)), 
        column(width=3, numericInput("perm_num", "permutation", value = 0, min = 0, max = 1000)), 
        column(width=3, selectInput("scaleC", "Scale method", c("center", "pareto", "standard"), selected = "standard"))
        
    ), 
     
    h3("1). The results for OPLS-DA:", style = "color: black; font-size: 17px"),
    downloadButton('OPLS_text_down', 'Download'),
    p(verbatimTextOutput("OPLS_text"), style = "color: black; font-size: 17px"),
    
    h3("2). The variable importance of projection for OPLS-DA:", style = "color: black; font-size: 17px"),
    downloadButton('OPLS_table_down', 'Download'),
    br(), br(), 
    fluidRow(
        column(width = 12,  
               DT::dataTableOutput("OPLS_table")
        )
    )
    
)
     
#       box(title=strong("The Resulting Dataset Table Generated by OPLS-DA"), solidHeader = T, status = "info", width=12,  collapsible=T,
#           (source("src/uicontrol/waitingPrompt.R",local=T)$value),
#           downloadButton('oplsda_table_down', 'Download'), 
#           p(strong("Table 1. Results for OPLS-DA"), style = "color:black; font-size:16px", align = "center"),  
#           DT::dataTableOutput("oplsda_table")
#       )
  ),
  conditionalPanel("!output.ShowUI",
                   box(title=NULL,solidHeader=F,width=12,
                       strong("Please upload your data in the ",span("'Data Upload/Integration'",style="text-decoration:underline"), "panel.", 
                              style = "color:rgba(255, 36, 0, 0.9); font-size: 17px")
                   )
  ),
  source("src/uicontrol/page_tail.R",local=T)$value
)
