fluidRow(
  box(title = strong("Partial Least Squares Discriminant Analysis (PLS-DA)"), solidHeader = T, status = "warning", width = 12,collapsible=T,
      p("PLS-DA is a chemometrics technique used for classification purposes either to infer variables that maximize the 
        discrimination between predefined sample groups or to predict class affiliations of unclassified samples based on 
        a calibration set of known class distributions. PLS-DA has been widely applied in metabolomics analysis to represent 
        a global metabolic profile of animal and human tissues (",
        span(a(em("Nat Protoc.")," 2013. 8(1): 17-32", style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/23222455",target="_black")),
        "), characterize the metabolomicpattern of hepatocellular carcinoma (",
        span(a(em("Cancer Res.")," 2013. 73(16): 4992-5002",style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/23824744",target="_black")),
        "), and explore urinary metabolic biomarkers and pathways (",
        span(a(em("Analyst.")," 2012. 137(18): 4200-8",style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/22852134",target="_black")), ").",
        style = "color: black; font-size: 17px"
      )
  ),
  conditionalPanel("output.ShowUI",
      box(title = strong("The Resulting Analysis Figures Generated by PLS-DA"), solidHeader = T, status = "info", width = 12, collapsible=T,
          #(source("src/uicontrol/waitingPrompt.R",local=T)$value),
          conditionalPanel("!output.plsda_table",
                           (source("src/uicontrol/waitingPrompt.R", local=T)$value)
          ),
          
          
          fluidRow(
              column(width=3, numericInput("prcom_num", "Number of PCs", value = 2, min = 2, max = 9)), 
              column(width=3, numericInput("ite_times", "Max Iterations", value = 500, min = 100, max = 1000)), 
              column(width=3, selectInput("tol_ite", "Tolerance in iteration", c(1e-04, 1e-05, 1e-06, 1e-07, 1e-08), selected = 1e-06))
              #,
              #column(width=3, selectInput("near_zero", "Near.zero.var", c(TRUE, FALSE), selected = TRUE))
          ),
          
          
          box(title = strong("Figure 1. Score plot", style = "color:black; font-size:16px"), solidHeader = FALSE, width = 6, 
              downloadButton('plsda1_plot_down', 'Download'), 
              br(), 
              plotOutput("plsda1_plot", height = 500)), 
          box(title = strong("Figure 2. VIP plot", style = "color:black; font-size:16px"), solidHeader = FALSE, width = 6, 
              downloadButton('plsda2_plot_down', 'Download'), 
              br(), 
              plotOutput("plsda2_plot", height = 500))
          
      ), 
      
      box(title=strong("The Resulting Dataset Table Generated by PLS-DA"), solidHeader = T, status = "info", width=12,  collapsible=T,
          downloadButton('plsda_table_down', 'Download'), 
          #p(strong("Table 1. Results for PLS-DA"), style = "color:black; font-size:16px", align = "center"),  
          br(), br(), 
          DT::dataTableOutput("plsda_table")
          
      )
  ),
  conditionalPanel("!output.ShowUI",
                   box(title=NULL,solidHeader=F,width=12,
                       strong("Please upload your data in the ",span("'Data Upload/Integration'",style="text-decoration:underline"), "panel.", 
                              style = "color:rgba(255, 36, 0, 0.9); font-size: 17px")
                   )
  ),
  source("src/uicontrol/page_tail.R",local=T)$value
)
