library(shinyBS)
fluidRow(
  box(title = strong("Support Vector Machine with Recursive Feature Elimination (SVM-RFE)"), collapsible=T,
      solidHeader = T,status = "warning", width = 12,
      p("SVM-RFE is a wrapper approach that uses the norm of the weights w to rank the variables. Initially, all data is 
        taken and a classifier is computed. The norm of w is then computed for each of the features and the feature with 
        the smallest norm is eliminated. This process is repeated until all the features are ranked. SVM-RFE has been 
        applied to determine differences between healthy subjects and patients suffering from Streptococcus pneumoniae (",
        span(a(em("Anal Chem.")," 2008. 80(19): 7562-70",style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/18767870",target="_black")),
        "), and interrogate the serum metabolome of early-stage ovarian cancer patients and age-matched control women (",
        span(a(em("Sci Rep.")," 2015. 5: 16351",style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/26573008",target="_black")), ").", 
        style = "color: black; font-size: 17px"
      )
  
  ),
  conditionalPanel("output.ShowUI",
        box(title=strong("The Resulting Dataset Table Generated by SVM-RFE"), solidHeader = T, status = "info", width=12,  collapsible=T,
            #(source("src/uicontrol/underConstruction.R")$value),
            conditionalPanel("!output.SVMRFE_table",
                             (source("src/uicontrol/waitingPrompt.R", local=T)$value)
            ),
            
            fluidRow(
                column(width=3, numericInput("c_value", "C Value in SVM model", value = 100, min = 1, max = 100000)), 
                column(width=3, selectInput("scaling_svm", "Data Scaling", c(FALSE), selected = FALSE))
            ), 
            downloadButton('SVMRFE_table_down', 'Download'),
            
            p(strong("Table 1. Results for SVM-RFE"), style = "color:black; font-size:16px", align = "center"),
            DT::dataTableOutput("SVMRFE_table")
            
            #actionButton("svmrfe_submit",label="submit"),
            #uiOutput("svmrfe_link")
        )
  ),
  conditionalPanel("!output.ShowUI",
                   box(title=NULL,solidHeader=F,width=12,
                       strong("Please upload your data in the ",span("'Data Upload/Integration'",style="text-decoration:underline"), "panel.", 
                              style = "color:rgba(255, 36, 0, 0.9); font-size: 17px")
                   )
  ),
  source("src/uicontrol/page_tail.R",local=T)$value
)
