fluidRow(
  box(title = strong("Random Forest with Recursive Feature Elimination (RF-RFE)"), solidHeader = T,status = "warning", width = 12,collapsible=T,
      p("RF-RFE is a recursive backward feature elimination procedure. It begins with all the features. In each iteration, 
        a random forest is constructed to measure the features’ importance and the feature with least importance is removed. 
        This procedure is repeated until there is no feature left. Finally, the features are ranked according to the deleted 
        sequence, and the top ranked feature is the last deleted one. RF-RFE has been applied to reveal the deregulation 
        of fatty acids metabolism in hepatocellular carcinoma and chronic liver diseases (",
        span(a(em("Anal Bioanal Chem.")," 2012. 403(1): 203-13",style="color:blue", href="http://www.ncbi.nlm.nih.gov/pubmed/22349331",target="_black")),
        "), and investigate hepatitis C by using metabolomics as a tool (",
        span(a(em("Metabolomics.")," 2012. 18(13): 3677-85", style="color:blue", href="http://link.springer.com/article/10.1007%2Fs11306-012-0467-8",target="_black")), ").", 
        style = "color: black; font-size: 17px"
      )
  ),
  
  conditionalPanel("output.ShowUI",
      box(title = strong("The Resulting Analysis Figures Generated by RF-RFE"), solidHeader = T, status = "info", width = 12, #collapsible=T,
          conditionalPanel("!output.rf_table",
                           (source("src/uicontrol/waitingPrompt.R", local=T)$value)
          ),
          
          fluidRow(
              column(width=3, numericInput("tree_num", "Number of Trees", value = 500, min = 100, max = 10000)), 
              column(width=3, numericInput("ntI_value", "ncI value", value = 300, min = 100, max = 10000)), 
              column(width=3, numericInput("vdf_value", "vars.drop.frac", value = 0.2, min = 0, max = 1)), 
              column(width=3, numericInput("seed_value", "set seed", value = 1, min = 1, max = 10000))
          ),  
          downloadButton('rf_plot_down', 'Download'),
          
          
           p(strong("Figure 1. Visualization Results for RF-RFE"), style = "color:black; font-size:16px", align = "center"),
           plotOutput("rf_plot"), 
          br(), br(), 
          p(paste("In total,", "markers were selected in RF-RFE method:", sep = " "), 
                 style = "color: black; font-size: 17px"),
          p(verbatimTextOutput("rf_text"), style = "color: black; font-size: 17px"), 
          br(), 
          p(strong("Table 1. Results for RF-RFE"), style = "color:black; font-size:16px", align = "center"), 
          downloadButton('rf_table_down', 'Download'), 
          br(), br(), 
          dataTableOutput("rf_table")
          
          #source("src/uicontrol/underConstruction.R")$value)
          )
#       box(title=strong("Result 2 - Detail Data Table"), solidHeader = T, status = "info", width=12, collapsible=T,
#           downloadButton('rf_table_down', 'Download'), 
#           br(), 
#           p(paste("In total,", "markers were selected in RF-RFE method:", sep = " "), 
#                  style = "color: black; font-size: 17px"), 
##            textOutput("rf_text"), 
#           p(verbatimTextOutput("rf_text"), style = "color: black; font-size: 17px"),
#           br(), 
#           p(strong("Table 1. Results for RF-RFE"), style = "color:black; font-size:16px", align = "center"),
#           dataTableOutput("rf_table"))
  ),
  conditionalPanel("!output.ShowUI",
                   box(title=NULL,solidHeader=F,width=12,
                       strong("Please upload your data in the ",span("'Data Upload/Integration'",style="text-decoration:underline"), "panel.", 
                              style = "color:rgba(255, 36, 0, 0.9); font-size: 17px")
                   )
  ),
  source("src/uicontrol/page_tail.R",local=T)$value
)
